==> my2cego-1.0.2.tar.gz: my2cego-1.0.2/src/My2CegoMain.cc <==
///////////////////////////////////////////////////////////////////////////////
//                                                         
// My2CegoMain.cc
// --------------
// My2Cego client program
//
// Design and Implementation by Bjoern Lemke               
//                                                         
// (C)opyright 2010 Bjoern Lemke                        
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option)
// any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; see the file COPYING.  If not, write to
// the Free Software Foundation, 59 Temple Place - Suite 330,
// Boston, MA 02111-1307, USA.
//
// IMPLEMENTATION MODULE
//
// Class: main
// 
// Description: 
//
// Status: XXX
//
///////////////////////////////////////////////////////////////////////////////

#include <locale.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <readline/readline.h>
#include <readline/history.h>

#include <lfc/Chain.h>
#include <lfc/Exception.h>
#include <lfc/GetLongOpt.h>
#include <lfc/File.h>
#include <lfc/Tokenizer.h>
#include <cego/CegoNet.h>

#include "My2CegoAction.h"

#define MY2CEGO_PRODUCT "My2Cego"
#define MY2CEGO_VERSION "1.0.2"
#define MY2CEGO_COPYRIGHT "Copyright (C) 2010 by Bjoern Lemke. All rights reserved"

#define USAGE "Usage: my2cego --user=<user>/<password>\n\
          [ --server=<host>]\n\
          [ --port=<port> ]\n\
	  [ --tableset=<tableset> ]\n\
          [ --mysqlfile=<batchfile> ]\n\
          [ --logfile=<logfile> ]\n\
          [ --nocasesensitive ]\n\
          [ --dump ]\n\
          [ --debug ] [ --version  ] [ --help ]"


#define DEFAULTPORT 2200
#define DEFAULTSERVER "localhost"
#define DEFAULTMYSQLFILE "mysqldump.sql"

// size info buffer len
#define SIZEBUFLEN 10
#define MSGBUFLEN 500 


#define HISTFILE ".cgclt_history"
#define PROMPT "CGCLT > "
#define PROMPT2 "> "


#define LANGUAGE_ENV "LANG"
#define LOCALE_CATEGORY LC_TIME

extern char __lfcVersionString[];
extern char __lfcxmlVersionString[];


int main(int argc, char **argv)
{	
    
    GetLongOpt longOpt(argc, argv);
    
    longOpt.addOpt("version");
    longOpt.addOpt("help");
    longOpt.addOpt("logfile");
    longOpt.addOpt("tableset");
    longOpt.addOpt("user");
    longOpt.addOpt("mysqlfile");
    longOpt.addOpt("debug");
    longOpt.addOpt("server", DEFAULTSERVER);
    longOpt.addOpt("port", Chain(DEFAULTPORT));
    longOpt.addOpt("nocasesensitive");
    longOpt.addOpt("dump");
    
    try
    {
	longOpt.parseOpt(); 
    }
    catch ( Exception e )
    {
	Chain msg;
	e.pop(msg);
	cerr << msg << endl;
	cerr << USAGE << endl;
	exit(1);	
    }
    
    Chain user;
    Chain password;
    

#ifdef HAVE_MINGW32
    Chain homeDir(getenv("HOMEPATH"));
    Chain histPath = homeDir + "\\" + Chain(HISTFILE);
#else
    Chain homeDir(getenv("HOME"));
    Chain histPath = homeDir + "/" + Chain(HISTFILE);
#endif


    try
    {
    
	bool debug=false;
	if ( longOpt.isSet("debug") )
	    debug=true;
	
	bool isCaseSensitive = true;
	if ( longOpt.isSet("nocasesensitive") )
	    isCaseSensitive=false;
	
	bool doDump = false;
	if ( longOpt.isSet("dump") )
	    doDump=true;
	
	
	if ( longOpt.isSet( Chain("help") ) )
	{	
	    cerr << USAGE << endl;
	    exit(0);
	}
	
	if ( longOpt.isSet( Chain("version") ) )
	{
	    cout << MY2CEGO_PRODUCT << " (" << sizeof(long) * 8 << " bit), Version " << MY2CEGO_VERSION 
		 << " [ lfc : " << __lfcVersionString  
		 << ", lfcxml : " <<  __lfcxmlVersionString << " ]" << endl;
	    cout << MY2CEGO_COPYRIGHT << endl;
	    exit(0);
	}

	Chain logFile = longOpt.getOptValue("logfile");
	Chain serverName = longOpt.getOptValue("server");
	Chain tableSet = longOpt.getOptValue("tableset");
	int portNo = longOpt.getOptValue("port").asInteger();
	
	Chain mysqlFileName;
	Chain command;
	
	if ( longOpt.isSet("mysqlfile") )
	{
	    mysqlFileName = longOpt.getOptValue("mysqlfile");
	}
	else
	{
	    mysqlFileName = Chain(DEFAULTMYSQLFILE);
	}

	if ( doDump == false )
	{
	    Chain authString = longOpt.getOptValue("user");
	    
	    Tokenizer authTok(authString, Chain("/")); 
	    authTok.nextToken(user);
	    authTok.nextToken(password);
	    
	    if ( user.length() == 0 )
	    {
		cerr << "User not set" << endl;
		exit (1);
	    }
	    if ( password.length() == 0 )
	    {
		cerr << "Password not set" << endl;
		exit (1);
	    }
	    if ( tableSet.length() == 0 )
	    {
		cerr << "Tableset not set" << endl;
		exit (1);
	    }
	    
	    // for localization
	    char* lang = 0;
	    if ( ( lang = getenv(LANGUAGE_ENV) ) != 0)
	    {
		if ( setlocale(LOCALE_CATEGORY, lang) == 0)
		{
		    Chain msg = Chain("Cannot set locale ") + Chain(lang);
		    cerr << msg << endl;
		    exit(1);
		}
	    }
	}
	
	int lineNo=0;
	
	CegoNet *pCegoNet = 0;

	Chain logMode("notice");
	if ( debug )
	    logMode=Chain("debug");

	if ( doDump == false )
	{
	    pCegoNet = new CegoNet( logFile, logMode );	    
	    pCegoNet->connect(serverName, portNo, tableSet, user, password);
	}

	My2CegoAction pa(mysqlFileName, pCegoNet, isCaseSensitive);
	
	cout << "Parsing .." << endl;
	pa.parse();
	
	if ( doDump == false )
	{
	    pCegoNet->disconnect();
	    delete pCegoNet;
	}
    }
    catch ( Exception e )
    {
	Chain msg;
	e.pop(msg);
	cout << msg << endl;
    }

    exit(0);
}

==> my2cego-1.1.0.tar.gz: my2cego-1.1.0/src/My2CegoMain.cc <==
///////////////////////////////////////////////////////////////////////////////
//                                                         
// My2CegoMain.cc
// --------------
// My2Cego client program
//
// Design and Implementation by Bjoern Lemke               
//                                                         
// (C)opyright 2010,2011,2012 Bjoern Lemke                        
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option)
// any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; see the file COPYING.  If not, write to
// the Free Software Foundation, 59 Temple Place - Suite 330,
// Boston, MA 02111-1307, USA.
//
// IMPLEMENTATION MODULE
//
// Class: main
// 
// Description: 
//
// Status: XXX
//
///////////////////////////////////////////////////////////////////////////////

#include <locale.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <readline/readline.h>
#include <readline/history.h>

#include <lfc/Chain.h>
#include <lfc/Exception.h>
#include <lfc/GetLongOpt.h>
#include <lfc/File.h>
#include <lfc/Tokenizer.h>
#include <cego/CegoNet.h>

#include "My2CegoAction.h"

#define MY2CEGO_PRODUCT "My2Cego"
#define MY2CEGO_VERSION "1.1.0"
#define MY2CEGO_COPYRIGHT "Copyright (C) 2010,2011,2012 by Bjoern Lemke. All rights reserved"

#define USAGE "Usage: my2cego --user=<user>/<password>\n\
          [ --server=<host>]\n\
          [ --port=<port> ]\n\
          [ --protocol=<protocol> ]\n\
	  [ --tableset=<tableset> ]\n\
          [ --mysqlfile=<batchfile> ]\n\
          [ --logfile=<logfile> ]\n\
          [ --nocasesensitive ]\n\
          [ --dump ]\n\
          [ --debug ] [ --version  ] [ --help ]"


#define DEFAULTPORT 2200
#define DEFAULTSERVER "localhost"
#define DEFAULTMYSQLFILE "mysqldump.sql"
#define DEFAULTPROTOCOL "xml"

// size info buffer len
#define SIZEBUFLEN 10
#define MSGBUFLEN 500 


#define HISTFILE ".cgclt_history"
#define PROMPT "CGCLT > "
#define PROMPT2 "> "


#define LANGUAGE_ENV "LANG"
#define LOCALE_CATEGORY LC_TIME

extern char __lfcVersionString[];
extern char __lfcxmlVersionString[];


int main(int argc, char **argv)
{	
    
    GetLongOpt longOpt(argc, argv);
    
    longOpt.addOpt("version");
    longOpt.addOpt("help");
    longOpt.addOpt("logfile");
    longOpt.addOpt("tableset");
    longOpt.addOpt("user");
    longOpt.addOpt("mysqlfile");
    longOpt.addOpt("debug");
    longOpt.addOpt("server", DEFAULTSERVER);
    longOpt.addOpt("port", Chain(DEFAULTPORT));
    longOpt.addOpt("nocasesensitive");
    longOpt.addOpt("dump");
    longOpt.addOpt("protocol", Chain(DEFAULTPROTOCOL));
    
    try
    {
	longOpt.parseOpt(); 
    }
    catch ( Exception e )
    {
	Chain msg;
	e.pop(msg);
	cerr << msg << endl;
	cerr << USAGE << endl;
	exit(1);	
    }
    
    Chain user;
    Chain password;
    

#ifdef HAVE_MINGW32
    Chain homeDir(getenv("HOMEPATH"));
    Chain histPath = homeDir + "\\" + Chain(HISTFILE);
#else
    Chain homeDir(getenv("HOME"));
    Chain histPath = homeDir + "/" + Chain(HISTFILE);
#endif


    try
    {
    
	bool debug=false;
	if ( longOpt.isSet("debug") )
	    debug=true;
	
	bool isCaseSensitive = true;
	if ( longOpt.isSet("nocasesensitive") )
	    isCaseSensitive=false;
	
	bool doDump = false;
	if ( longOpt.isSet("dump") )
	    doDump=true;
	
	
	if ( longOpt.isSet( Chain("help") ) )
	{	
	    cerr << USAGE << endl;
	    exit(0);
	}
	
	if ( longOpt.isSet( Chain("version") ) )
	{
	    cout << MY2CEGO_PRODUCT << " (" << sizeof(long) * 8 << " bit), Version " << MY2CEGO_VERSION 
		 << " [ lfc : " << __lfcVersionString  
		 << ", lfcxml : " <<  __lfcxmlVersionString << " ]" << endl;
	    cout << MY2CEGO_COPYRIGHT << endl;
	    exit(0);
	}

	Chain logFile = longOpt.getOptValue("logfile");
	Chain serverName = longOpt.getOptValue("server");
	Chain tableSet = longOpt.getOptValue("tableset");
	int portNo = longOpt.getOptValue("port").asInteger();
	
	Chain mysqlFileName;
	Chain command;
	
	if ( longOpt.isSet("mysqlfile") )
	{
	    mysqlFileName = longOpt.getOptValue("mysqlfile");
	}
	else
	{
	    mysqlFileName = Chain(DEFAULTMYSQLFILE);
	}

	CegoDbHandler::ProtocolType protType;

	Chain prot = longOpt.getOptValue("protocol");
	
	if ( prot == Chain("serial") )
	{
	    protType = CegoDbHandler::SERIAL;
	}
	else if ( prot == Chain("xml") )
	{
	    protType = CegoDbHandler::XML;
	}
	else
	{
	    cerr << "Invalid protocol " << prot;
	    exit (1);
	}


	if ( doDump == false )
	{
	    Chain authString = longOpt.getOptValue("user");
	    
	    Tokenizer authTok(authString, Chain("/")); 
	    authTok.nextToken(user);
	    authTok.nextToken(password);
	    
	    if ( user.length() == 0 )
	    {
		cerr << "User not set" << endl;
		exit (1);
	    }
	    if ( password.length() == 0 )
	    {
		cerr << "Password not set" << endl;
		exit (1);
	    }
	    if ( tableSet.length() == 0 )
	    {
		cerr << "Tableset not set" << endl;
		exit (1);
	    }
	    
	    // for localization
	    char* lang = 0;
	    if ( ( lang = getenv(LANGUAGE_ENV) ) != 0)
	    {
		if ( setlocale(LOCALE_CATEGORY, lang) == 0)
		{
		    Chain msg = Chain("Cannot set locale ") + Chain(lang);
		    cerr << msg << endl;
		    exit(1);
		}
	    }
	}
	
	int lineNo=0;
	
	CegoNet *pCegoNet = 0;

	Chain logMode("notice");
	if ( debug )
	    logMode=Chain("debug");

	if ( doDump == false )
	{
	    pCegoNet = new CegoNet( protType, logFile, logMode );
	    pCegoNet->connect(serverName, portNo, tableSet, user, password);
	}

	My2CegoAction pa(mysqlFileName, pCegoNet, isCaseSensitive);
	
	cout << "Parsing .." << endl;
	pa.parse();
	
	if ( doDump == false )
	{
	    pCegoNet->disconnect();
	    delete pCegoNet;
	}
    }
    catch ( Exception e )
    {
	Chain msg;
	e.pop(msg);
	cout << msg << endl;
    }

    exit(0);
}
